==> kadu_0.5.0.orig.tar.gz: profiles/translations/profiles_pl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>ConfigurationWindow</name>
    <message>
        <source>Profile Manager</source>
        <translation>Menedżer profili</translation>
    </message>
    <message>
        <source>Profile Settings</source>
        <translation>Ustawienia profilu</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>UIN</source>
        <translation>UIN</translation>
    </message>
    <message>
        <source>Directory</source>
        <translation>Katalog</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Zaawansowane</translation>
    </message>
    <message>
        <source>Copy Configuration</source>
        <translation>Kopiuj konfigurację</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Run</source>
        <translation>Uruchom</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Profile Name contains wrong characters (&quot;..&quot;).</source>
        <translation>Nazwa profilu zawiera niepoprawne znaki (&quot;..&quot;).</translation>
    </message>
    <message>
        <source>Are you sure to continue? Directory (with all contents) will be deleted.</source>
        <translation>Jesteś pewien? Katalog profilu wraz z całą zawartością zostanie usunięty.</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Copy Userlist</source>
        <translation>Kopiuj listę kontaktów</translation>
    </message>
    <message>
        <source>Autostart</source>
        <translation>Uruchamiaj automatycznie</translation>
    </message>
    <message>
        <source>Please write at least the name of the Profile</source>
        <translation>Proszę podać co najmniej nazwę dla profilu</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nowy</translation>
    </message>
</context>
<context>
    <name>ProfileManager</name>
    <message>
        <source>Profile Manager</source>
        <translation>Menedżer profili</translation>
    </message>
    <message>
        <source>Please remember that all profile history and settings are stored in your home directory. 
Creating profile for other system users is not recommended because of security reasons. 
The recommended solution is to create user in system for every person which will use Kadu. 
Please notice that this module is contradictory with Linux system ideology and was provided for compatibility with Gadu-Gadu.</source>
        <translation>Pamiętaj, że zarówno historia jak i ustawienia profilu są zapisywane w twoim katalogu domowym.
Tworzenie profili dla innych osób nie jest zalecane ze względów bezpieczeństwa. Jeśli chcesz umożliwić
innym osobom korzystanie z komunikatora rozważ stworzenie im osobnych użytkowników w systemie.

Zwróć uwagę, że ten moduł jest niezgodny z filozofią Linuxa i został stworzony w celu zapewnienia
kompatybilności z Gadu-gadu w kwestii profili użytkownika.
</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nowy</translation>
    </message>
</context>
</TS>

==> kadu_0.6.0.2.orig.tar.gz: profiles/translations/profiles_pl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>ConfigurationWindow</name>
    <message>
        <source>Profile Manager</source>
        <translation type="obsolete">Menedżer profili</translation>
    </message>
    <message>
        <source>Profile Settings</source>
        <translation type="obsolete">Ustawienia profilu</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="obsolete">Nazwa</translation>
    </message>
    <message>
        <source>UIN</source>
        <translation type="obsolete">UIN</translation>
    </message>
    <message>
        <source>Directory</source>
        <translation type="obsolete">Katalog</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation type="obsolete">Zaawansowane</translation>
    </message>
    <message>
        <source>Copy Configuration</source>
        <translation type="obsolete">Kopiuj konfigurację</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="obsolete">Dodaj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="obsolete">Usuń</translation>
    </message>
    <message>
        <source>Run</source>
        <translation type="obsolete">Uruchom</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="obsolete">Zamknij</translation>
    </message>
    <message>
        <source>Profile Name contains wrong characters (&quot;..&quot;).</source>
        <translation type="obsolete">Nazwa profilu zawiera niepoprawne znaki (&quot;..&quot;).</translation>
    </message>
    <message>
        <source>Are you sure to continue? Directory (with all contents) will be deleted.</source>
        <translation type="obsolete">Jesteś pewien? Katalog profilu wraz z całą zawartością zostanie usunięty.</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">Hasło</translation>
    </message>
    <message>
        <source>Copy Userlist</source>
        <translation type="obsolete">Kopiuj listę kontaktów</translation>
    </message>
    <message>
        <source>Autostart</source>
        <translation type="obsolete">Uruchamiaj automatycznie</translation>
    </message>
    <message>
        <source>Please write at least the name of the Profile</source>
        <translation type="obsolete">Proszę podać co najmniej nazwę dla profilu</translation>
    </message>
    <message>
        <source>New</source>
        <translation type="obsolete">Nowy</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>The profile is protected by password.
Please provide the password and press Ok.</source>
        <translation>Profil jest zabezpieczony hasłem.
Proszę podać hasło i nacisnąć Ok.</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>ProfileConfigurationWindow</name>
    <message>
        <source>Profile Manager</source>
        <translation>Menedżer profili</translation>
    </message>
    <message>
        <source>Profile Settings</source>
        <translation>Ustawienia profilu</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>UIN</source>
        <translation>UIN</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Directory</source>
        <translation>Katalog</translation>
    </message>
    <message>
        <source>Password Protected</source>
        <translation>Zabezpiecz hasłem</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Zaawansowane</translation>
    </message>
    <message>
        <source>Copy Configuration</source>
        <translation>Kopiuj konfigurację</translation>
    </message>
    <message>
        <source>Copy Userlist</source>
        <translation>Kopiuj listę kontaktów</translation>
    </message>
    <message>
        <source>Autostart</source>
        <translation>Uruchamiaj automatycznie</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="obsolete">Dodaj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Run</source>
        <translation>Uruchom</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Please write at least the name of the Profile</source>
        <translation>Proszę podać co najmniej nazwę dla profilu</translation>
    </message>
    <message>
        <source>Profile Name contains wrong characters (&quot;..&quot;).</source>
        <translation>Nazwa profilu zawiera niepoprawne znaki (&quot;..&quot;).</translation>
    </message>
    <message>
        <source>The password is invalid. Sorry</source>
        <translation>Podane hasło jest nieprawidłowe. Spróbuj ponownie</translation>
    </message>
    <message>
        <source>Are you sure to continue? Directory (with all contents) will be deleted.</source>
        <translation>Jesteś pewien? Katalog profilu wraz z całą zawartością zostanie usunięty.</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nowy</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
</context>
<context>
    <name>ProfileManager</name>
    <message>
        <source>Profile Manager</source>
        <translation>Menedżer profili</translation>
    </message>
    <message>
        <source>Please remember that all profile history and settings are stored in your home directory. 
Creating profile for other system users is not recommended because of security reasons. 
The recommended solution is to create user in system for every person which will use Kadu. 
Please notice that this module is contradictory with Linux system ideology and was provided for compatibility with Gadu-Gadu.</source>
        <translation>Pamiętaj, że zarówno historia jak i ustawienia profilu są zapisywane w twoim katalogu domowym.
Tworzenie profili dla innych osób nie jest zalecane ze względów bezpieczeństwa. Jeśli chcesz umożliwić
innym osobom korzystanie z komunikatora rozważ stworzenie im osobnych użytkowników w systemie.

Zwróć uwagę, że ten moduł jest niezgodny z filozofią Linuxa i został stworzony w celu zapewnienia
kompatybilności z Gadu-gadu w kwestii profili użytkownika.
</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nowy</translation>
    </message>
    <message>
        <source>The password is invalid. Sorry</source>
        <translation>Podane hasło jest nieprawidłowe. Spróbuj ponownie</translation>
    </message>
    <message>
        <source>Profiles...</source>
        <translation>Profile...</translation>
    </message>
    <message>
        <source>No profiles</source>
        <translation>Brak profili</translation>
    </message>
</context>
</TS>
